@@ -1,7 +1,7 @@
 # This module handles input and output of PDB files.
 #
 # Written by Konrad Hinsen <hinsen@cnrs-orleans.fr>
-# Last revision: 2001-1-11
+# Last revision: 2003-8-20
 # 
 
 """This module provides classes that represent PDB (Protein Data Bank)
@@ -70,7 +70,7 @@ generic_format = FortranFormat('A6,A74')
 amino_acids = ['ALA', 'ARG', 'ASN', 'ASP', 'CYS', 'CYX', 'GLN', 'GLU', 'GLY',
                'HIS', 'HID', 'HIE', 'HIP', 'HSD', 'HSE', 'HSP', 'ILE', 'LEU',
                'LYS', 'MET', 'PHE', 'PRO', 'SER', 'THR', 'TRP', 'TYR', 'VAL',
-               'ACE', 'NME']
+               'ACE', 'NME', 'NHE']
 
 nucleic_acids = [ 'A',  'C',  'G',  'I',  'T',  'U',
                  '+A', '+C', '+G', '+I', '+T', '+U',
@@ -533,7 +533,7 @@ class Group:
         if type(file) == type(''):
             file = PDBFile(file, 'w')
             close = 1
-        file.nextResidue(self.name, self.number, self.terminusType())
+        file.nextResidue(self.name, self.number, None)
         for a in self.atom_list:
             a.writeToFile(file)
         if close:
